#!/usr/bin/env bash
set -e

if [ -z "$MYSQL_PORT_3306_TCP_ADDR" ]; then
	: ${MYSQL_PORT_3306_TCP_ADDR:=mysql}
fi

# if we're linked to MySQL, and we're using the root user, and our linked
# container has a default "root" password set up and passed through... :)
: ${ETHERPAD_DB_USER:=root}
if [ "$ETHERPAD_DB_USER" = 'root' ]; then
	: ${ETHERPAD_DB_PASSWORD:=$MYSQL_ENV_MYSQL_ROOT_PASSWORD}
fi
: ${ETHERPAD_DB_NAME:=etherpad}

ETHERPAD_DB_NAME=$( echo $ETHERPAD_DB_NAME | sed 's/\./_/g' )

if [ -z "$ETHERPAD_DB_PASSWORD" ]; then
	echo >&2 'error: missing required ETHERPAD_DB_PASSWORD environment variable'
	echo >&2 '  Did you forget to -e ETHERPAD_DB_PASSWORD=... ?'
	echo >&2
	echo >&2 '  (Also of interest might be ETHERPAD_DB_USER and ETHERPAD_DB_NAME.)'
	exit 1
fi

# Title of the instance
: ${ETHERPAD_TITLE:=Picapad}
: ${ETHERPAD_PORT:=8080}

# Skin of the instance ; for now only no-skin and colibris exist
: ${ETHERPAD_THEME:=no-skin}

# If true, minify all CSS and JS but prevent debugging client-side
: ${ETHERPAD_MINIFY:=false}

# Default text when creating a new pad
: ${ETHERPAD_DEFAULT_TEXT:="Bienvenue sur Picapad, une instance d'Etherpad, un éditeur de texte collaboratif libre.\n\
-----------------------------------------------------------\n\
Le texte que vous saisissez est automatiquement synchronisé avec toutes les personnes naviguant sur ce pad.\n\n\
Prenez des notes et rédigez des documents librement !\n\n\
→ Pour bien commencer :\n\
• Renseignez votre nom ou pseudo, en cliquant sur l’icône « utilisateur » en haut à droite.\n\
• Choisissez votre couleur d'écriture au même endroit.\n\
• Les contributions de chacun se synchronisent « en temps réel » sous leur propre couleur.\n\
• Un chat vous permet de discuter avec les autres personnes présentes sur le pad.\n\n\
→ Fonctionnalités :\n\
• Couleur du texte, tableau, choix et taille de police, alignement, pleine page...\n\
• Sauvegarde automatique du pad.\n\
• Historique complet du pad (bouton en forme d'horloge)\n\
• Sauvegarde de versions clés (bouton en forme d'étoile).\n\
• Commentaires avec suggestion de remplacement (bouton en forme de bulle).\n\
• Les réglages vous permettent de désactiver les couleurs, de changer la langue, d'activer les sauts de pages...\n\n\
→ Partage :\n\
• Import et export dans divers formats (bouton avec les flèches).\n\
• Partage en lecture seule, pour éviter les modifications non voulues (bouton </>).\n\n\
Pensez à garder l'URL de votre pad pour le retrouver.\nAttention, celui-ci est public, c'est-à-dire que toute personne qui en possède l'URL pourra y accéder : \
n'y stockez pas d'informations confidentielles !\n\
-----------------------------------------------------------\n\
Une question ? Un problème ? Envoyez-nous un mail à picasoft@assos.utc.fr !"}

# Check if database already exists
RESULT=`mysql -u${ETHERPAD_DB_USER} -p${ETHERPAD_DB_PASSWORD} \
	-h${MYSQL_PORT_3306_TCP_ADDR} --skip-column-names \
	-e "SHOW DATABASES LIKE '${ETHERPAD_DB_NAME}'"`

if [ "$RESULT" != $ETHERPAD_DB_NAME ]; then
	# mysql database does not exist, create it
	echo "Creating database ${ETHERPAD_DB_NAME}"

	mysql -u${ETHERPAD_DB_USER} -p${ETHERPAD_DB_PASSWORD} -h${MYSQL_PORT_3306_TCP_ADDR} \
	      -e "create database ${ETHERPAD_DB_NAME}"
fi

cat <<- EOF > /opt/etherpad-lite/settings.json
{
  "title": "${ETHERPAD_TITLE}",
  "ip": "0.0.0.0",
  "port": "${ETHERPAD_PORT}",
  "dbType": "mysql",
  "dbSettings": {
    "user"    : "${ETHERPAD_DB_USER}",
    "host"    : "${MYSQL_PORT_3306_TCP_ADDR}",
    "password": "${ETHERPAD_DB_PASSWORD}",
    "database": "${ETHERPAD_DB_NAME}",
    "charset" : "utf8mb4"
  },
  "minify": "${ETHERPAD_MINIFY}",
  "skinName": "${ETHERPAD_THEME}",
  "defaultPadText": "${ETHERPAD_DEFAULT_TEXT}",
  "padOptions": {
	"lang": "fr",
	"userName": "Anonyme",
	"alwaysShowChat": false,
	"chatAndUsers": false
  },
  "allowUnknownFileEnds": false,
  "soffice": "/usr/bin/soffice",
EOF

if [ $ETHERPAD_ADMIN_PASSWORD ]; then

	: ${ETHERPAD_ADMIN_USER:=admin}

	cat <<- EOF >> /opt/etherpad-lite/settings.json
	  "users": {
	    "${ETHERPAD_ADMIN_USER}": {
	      "password": "${ETHERPAD_ADMIN_PASSWORD}",
	      "is_admin": true
	    }
	  }
	EOF
fi

cat <<- EOF >> /opt/etherpad-lite/settings.json
}
EOF

exec "$@"
